% Make data
n = 10001;
dt = 0.01;
time = [0:n-1]*dt;
data = sin(time);
variance = std(data)^2;
normal_data = (data - mean(data))/sqrt(variance);

xlim = [0,100];  % plotting range
mother = 'MORLET';

% Wavelet transform  where wave is the transformed data, period is 
% vector of "Fourier" periods (in time units) that corresponds to the
% scales, scale = the vector of scale indices, given by S0*2^(j*DJ), 
% j=0...J1 where J1+1 is the total # of scales, and coi is the Cone-of-Influence,
% which is a vector of N points that contains the maximum period of useful
% information at that particular time. Periods greater than this are subject
% to edge effects.
[wave,period,scale,coi] = wavelet(data,dt,1,0.01,-1,-1);
power = (abs(wave)).^2 ;        % compute wavelet power spectrum

% Significance levels: (variance=1 for the normalized data
[signif,fft_theor] = wave_signif(1.0,dt,scale,0,0,-1,-1,mother);
sig95 = (signif')*(ones(1,n));  % expand signif --> (J+1)x(N) array
sig95 = power ./ sig95;         % where ratio > 1, power is significant

%--- Plot time series
subplot(2,1,1)
plot(time,data)
set(gca,'XLim',xlim(:))
xlabel('Time')
ylabel('data')

% Pcolor wavelet power spectrum
subplot(2,1,2)
levels = [0.0625,0.125,0.25,0.5,1,2,4,8,16] ;
pcolor(time,period,power),shading flat,colormap hot
xlabel('Time')
ylabel('Period')
axis([0 100 0 20])

% 95% significance contour
hold on
contour(time,period,sig95,1,'w','LineWidth',3);

% cone-of-influence, anything "outside" is dubious
plot(time,coi,'r','LineWidth',2)
hold off
