% Make data
n = 10001;
dt = 0.01;
time = [0:n-1]*dt;
data = (sin(2*time)+sin(time)+sin(0.5*time)).*exp(-((time-50)/10).^2)+randn(1,n);
variance = std(data)^2;
normal_data = (data - mean(data))/sqrt(variance);

xlim = [0,100];  % plotting range
mother = 'MORLET';

% Wavelet transform:
[wave,period,scale,coi] = wavelet(data,dt,1,0.01,-1,-1);
power = (abs(wave)).^2 ;        % compute wavelet power spectrum

% Significance levels: (variance=1 for the normalized SST)
[signif,fft_theor] = wave_signif(1.0,dt,scale,0,0,-1,-1,mother);
sig95 = (signif')*(ones(1,n));  % expand signif --> (J+1)x(N) array
sig95 = power ./ sig95;         % where ratio > 1, power is significant

% % Global wavelet spectrum & significance levels:
% global_ws = variance*(sum(power')/n);   % time-average over all times
% dof = n - scale;  % the -scale corrects for padding at edges
% global_signif = wave_signif(variance,dt,scale,1,lag1,-1,dof,mother);
% 
% % Scale-average between El Nino periods of 2--8 years
% avg = find((scale >= 2) & (scale < 8));
% Cdelta = 0.776;   % this is for the MORLET wavelet
% scale_avg = (scale')*(ones(1,n));  % expand scale --> (J+1)x(N) array
% scale_avg = power ./ scale_avg;   % [Eqn(24)]
% scale_avg = variance*dj*dt/Cdelta*sum(scale_avg(avg,:));   % [Eqn(24)]
% scaleavg_signif = wave_signif(variance,dt,scale,2,lag1,-1,[2,7.9],mother);

%------------------------------------------------------ Plotting

%--- Plot time series
subplot(2,1,1)
plot(time,data)
set(gca,'XLim',xlim(:))
xlabel('Time')
ylabel('data')
hold off

%--- Pcolor wavelet power spectrum
subplot(2,1,2)
levels = [0.0625,0.125,0.25,0.5,1,2,4,8,16] ;
pcolor(time,period,power),shading flat,colormap hot
xlabel('Time')
ylabel('Period')
axis([0 100 0 20])

% 95% significance contour
hold on
contour(time,period,sig95,1,'w','LineWidth',3);
hold on
% cone-of-influence, anything "outside" is dubious
plot(time,coi,'r','LineWidth',2)
hold off

% %--- Plot global wavelet spectrum
% subplot('position',[0.77 0.37 0.2 0.28])
% plot(global_ws,log2(period))
% hold on
% plot(global_signif,log2(period),'--')
% hold off
% xlabel('Power (degC^2)')
% title('c) Global Wavelet Spectrum')
% set(gca,'YLim',log2([min(period),max(period)]), ...
% 	'YDir','reverse', ...
% 	'YTick',log2(Yticks(:)), ...
% 	'YTickLabel','')
% set(gca,'XLim',[0,1.25*max(global_ws)])
% 
% %--- Plot 2--8 yr scale-average time series
% subplot('position',[0.1 0.07 0.65 0.2])
% plot(time,scale_avg)
% set(gca,'XLim',xlim(:))
% xlabel('Time (year)')
% ylabel('Avg variance (degC^2)')
% title('d) 2-8 yr Scale-average Time Series')
% hold on
% plot(xlim,scaleavg_signif+[0,0],'--')
% hold off

% end of code
