load import_data.mat
date = datetime(datestr(time_epoch/86400 + datenum(1970,1,1)));
time = datenum(time_epoch/86400 + datenum(1970,1,1));
variance = std(temp)^2;
tempn = (temp - mean(temp))/sqrt(variance);
n=length(temp);
dt=0.5;
pad = 1;      % pad the time series with zeroes (recommended)
dj = 0.01;    % this will do 4 sub-octaves per octave
s0 = 2*dt;    % this says start at a scale of 6 months
j1 = 7/dj;    % this says do 7 powers-of-two with dj sub-octaves each
lag1 = 0.72;  % lag-1 autocorrelation for red noise background
mother = 'Morlet';

% Wavelet transform:
[wave,period,scale,coi] = wavelet(tempn,dt,pad,dj,s0,j1,mother);
power = (abs(wave)).^2 ;        % compute wavelet power spectrum

% Significance levels: (variance=1 for the normalized data)
[signif,fft_theor] = wave_signif(1.0,dt,scale,0,lag1,-1,-1,mother);
sig95 = (signif')*(ones(1,n));  % expand signif --> (J+1)x(N) array
sig95 = power ./ sig95;         % where ratio > 1, power is significant

%--- Plot time series
subplot(2,1,1)
plot(date,tempn)
xlabel('Date')
ylabel('Temp (normalized)')

% Pcolor wavelet power spectrum
subplot(2,1,2)
pcolor(time,period,power),shading flat,colormap hot
xlabel('Date')
ylabel('Period (hours)')

% 95% significance contour
hold on
contour(time,period,sig95,1,'w','LineWidth',3);

% cone-of-influence, anything "outside" is dubious
plot(time,coi,'r','LineWidth',2)
hold off

datetick('x','mmm dd','keepticks')
